--[[
    FuBar_MagicMarker - MagicMarker FuBar plugin
--]]

MMFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceDB-2.0")
local L = LibStub("AceLocale-3.0"):GetLocale("MagicMarker", false)
local C = LibStub("AceConfigDialog-3.0")
local T = AceLibrary("Tablet-2.0")

local MMFu = MMFu
local MM = MagicMarker
local MMDB = MagicMarkerDB

MMFu:RegisterDB("MMFuDB")
MMFu:RegisterDefaults('profile', { hideTitle = false })

MMFu.hasIcon = true
MMFu.canHideText = true
MMFu.canHideIcon = true
MMFu.defaultPosition = 'LEFT'
MMFu.blizzardTooltip = true
MMFu.cannotDetachTooltip = true

local db

local options = {
   type = "group",
   args = {
      config = { 
	 type = "toggle",
	 name =  L["Toggle config dialog"],
	 desc = L["Toggle the Magic Marker configuration dialog."],
	 set = "ToggleConfigDialog",
	 get = function() return C.OpenFrames["Magic Marker"] ~= nil end,
	 handler = MM,
	 order = 1
      }, 
      toggle = {
	 type = "toggle", 
	 name = L["Toggle event handling"],
	 desc = L["Enable or disable the event handling, i.e whether or not Magic Marker will insert mobs into the mob database, mark mobs etc."],
	 set = "ToggleMagicMarker",
	 get = function() return MM.addonEnabled end,
	 handler = MM,
	 order = 2
      },
      reset = {
	 type = "execute",
	 name = L["Reset raid icon cache"]..".",
	 desc = L["Reset the raid icon cache. Note that this honors the Magic Marker options such as preserve raid marks."],
	 func = "ResetMarkData",
	 handler = MM,
      },
      hideTitle = {
	 type = "toggle",
	 name = L["Short FuBar Text"],
	 desc = L["Hide Magic Marker from the FuBar status text."],
	 set = function() db.hideTitle = not db.hideTitle MMFu:Update() end,
	 get = function() return db.hideTitle end,
      },

      cache = {
	 type = "group",
	 name = L["Raid mark layout caching"],
	 desc = L["RAIDMARKCACHEHELP"],
	 order = 1000,
	 handler = MM,
	 args = {
	    save = {
	       type = "execute",
	       name = L["Save party/raid mark layout"],
	       desc = L["Save the current raid mark layout."],
	       func = "CacheRaidMarks",
	    },
	    load = {
	       type = "execute",
	       name = L["Load party/raid mark layout"],
	       desc = L["Load the currently saved raid mark layout."],
	       func = "MarkRaidFromCache",
	    },
	 }
      },
      tmpl = {
	 type = "group",
	 name = L["Raid group target templates"],
	 desc  = L["RAIDTMPLHELP"],
	 handler = MM,
	 order = 900
      },
   }
}
MMFu.OnMenuRequest = options

function MMFu:OnProfileEnable()
   db = self.db.profile 
end

local function capitalize(str)
   return strupper(str.sub(str,1,1))..str.sub(str, 2)
end



function MMFu:OnInitialize()
   db = self.db.profile
   if not options.args.tmpl.args then
      args = {}
      for cmd,data in pairs(MM.MarkTemplates) do
	 if cmd ~= "arch" then
	    args[cmd] = {
	       type = "execute",
	       name = string.format("%s: %s", capitalize(cmd), data.desc),
	       desc = data.desc,
	       func = function() MM:MarkRaidFromTemplate(cmd) end,
	    }
	 end
      end
      options.args.tmpl.args = args
   end
end

local function white(str)
   return string.format("|cffffffff%s|r", str)
end

local function yellow(str)
   return string.format("|cffffff00%s|r", str)
end

function MMFu:OnTextUpdate()
   if db.hideTitle then
      self:SetText(white((MM.addonEnabled and L["Enabled"]) or L["Disabled"]))
   else
      self:SetText(string.format("%s: |cffffffff%s|r", L["Magic Marker"],
				 (MM.addonEnabled and L["Enabled"]) or L["Disabled"]))
   end
end

function MMFu:OnClick()
   if IsAltKeyDown() then
      MM:ResetMarkData(IsShiftKeyDown())
   elseif IsShiftKeyDown() then
      MM:ToggleMagicMarker()
   else
      MM:ToggleConfigDialog()
   end
   
end

function MMFu:OnTooltipUpdate()
   local zone = GetRealZoneText()
   GameTooltip:AddLine( L["Magic Marker"] )
   GameTooltip:AddDoubleLine( L["Status"], white((MM.addonEnabled and L["Enabled"]) or L["Disabled"]))
   GameTooltip:AddDoubleLine( L["Zone"], white(zone))
   local zoneID, _, heroic = MM:GetZoneName(zone)
   if IsInInstance() then
      GameTooltip:AddDoubleLine( L["Difficulty"],  (heroic and L["Heroic"]) or L["Normal"])
   end
   if MMDB.mobdata[zoneID] then
      GameTooltip:AddLine("\n"..MM:GetZoneInfo(MMDB.mobdata[zoneID]))
   end
   GameTooltip:AddLine("\n"..yellow(L["Hint: Click to toggle config dialog."]))
   GameTooltip:AddLine(yellow(L["Shift-Click to toggle events."]))
   GameTooltip:AddLine(yellow(L["Alt-Click to reset raid icon cache."]))
   GameTooltip:AddLine(yellow(L["Alt-Shift-Click to hard reset raid icon cache."]))
end
